
# Slot: positively regulates




URI: [biolink:positively_regulates](https://w3id.org/biolink/vocab/positively_regulates)

## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [regulates](regulates.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
